=== modified file 'NEWS'
--- NEWS	2007-08-09 00:05:03 +0000
+++ NEWS	2007-08-09 03:34:54 +0000
@@ -206,6 +206,9 @@
     * Graph now has an is_ancestor method, various bits use it.
       (Aaron Bentley)
 
+    * The ``-Dhpss`` flag now includes timing information. As well as
+      logging when a new connection is opened. (John Arbash Meinel)
+
     * ``bzrlib.pack.ContainerWriter`` now returns an offset, length tuple to
       callers when inserting data, allowing generation of readv style access
       during pack creation, without needing a separate pass across the output

=== modified file 'bzrlib/smart/protocol.py'
--- bzrlib/smart/protocol.py	2007-08-02 06:40:58 +0000
+++ bzrlib/smart/protocol.py	2007-08-08 14:34:56 +0000
@@ -18,8 +18,8 @@
 client and server.
 """
 
-
 from cStringIO import StringIO
+import time
 
 from bzrlib import debug
 from bzrlib import errors
@@ -300,10 +300,12 @@
         """
         self._request = request
         self._body_buffer = None
+        self._request_start_time = None
 
     def call(self, *args):
         if 'hpss' in debug.debug_flags:
-            mutter('hpss call:   %r', args)
+            mutter('hpss call:   %s', repr(args)[1:-1])
+            self._request_start_time = time.time()
         self._write_args(args)
         self._request.finished_writing()
 
@@ -313,7 +315,9 @@
         After calling this, call read_response_tuple to find the result out.
         """
         if 'hpss' in debug.debug_flags:
-            mutter('hpss call w/body: %r (%r...)', args, body[:20])
+            mutter('hpss call w/body: %s (%r...)', repr(args)[1:-1], body[:20])
+            mutter('              %d bytes', len(body))
+            self._request_start_time = time.time()
         self._write_args(args)
         bytes = self._encode_bulk_data(body)
         self._request.accept_bytes(bytes)
@@ -326,12 +330,15 @@
         each pair are separated by a comma, and no trailing \n is emitted.
         """
         if 'hpss' in debug.debug_flags:
-            mutter('hpss call w/readv: %r', args)
+            mutter('hpss call w/readv: %s', repr(args)[1:-1])
+            self._request_start_time = time.time()
         self._write_args(args)
         readv_bytes = self._serialise_offsets(body)
         bytes = self._encode_bulk_data(readv_bytes)
         self._request.accept_bytes(bytes)
         self._request.finished_writing()
+        if 'hpss' in debug.debug_flags:
+            mutter('              %d bytes in readv request', len(readv_bytes))
 
     def cancel_read_body(self):
         """After expecting a body, a response code may indicate one otherwise.
@@ -349,7 +356,13 @@
         """
         result = self._recv_tuple()
         if 'hpss' in debug.debug_flags:
-            mutter('hpss result: %r', result)
+            if self._request_start_time is not None:
+                mutter('   result:   %6.3fs  %s',
+                       time.time() - self._request_start_time,
+                       repr(result)[1:-1])
+                self._request_start_time = None
+            else:
+                mutter('   result:   %s', repr(result)[1:-1])
         if not expect_body:
             self._request.finished_reading()
         return result
@@ -371,6 +384,9 @@
         self._request.finished_reading()
         self._body_buffer = StringIO(_body_decoder.read_pending_data())
         # XXX: TODO check the trailer result.
+        if 'hpss' in debug.debug_flags:
+            mutter('              %d body bytes read',
+                   len(self._body_buffer.getvalue()))
         return self._body_buffer.read(count)
 
     def _recv_tuple(self):

=== modified file 'doc/developers/profiling.txt'
--- doc/developers/profiling.txt	2007-07-27 05:57:27 +0000
+++ doc/developers/profiling.txt	2007-08-08 14:12:02 +0000
@@ -53,3 +53,12 @@
 At present this only logs actions relating to the on-disk lockdir.  It 
 doesn't describe actions on in-memory lock counters, or OS locks (which
 are used for dirstate.)
+
+
+Profiling HPSS Requests
+-----------------------
+
+When trying to improve network performance, it is often useful to know
+what requests are being made, and how long they are taking. The ``-Dhpss``
+global option will enable logging smart server requests, including the
+time spent in each request.

